@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: setup.php,v 1.9 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: setup.php,v 1.10 2008/09/23 09:06:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,6 @@ $config = array(
   'app_name'    => 'setup'
 );
 
-$controller =& SyL_Controller::getController($config);
-$controller->stream();
+SyL_Controller::streaming($config);
 
 ?>
