@@ -24,7 +24,9 @@ $config = array(
   'cache'        => false
 );
 
-$controller =& SyL_Controller::getController($config);
-$controller->stream();
+/**
+ * t[[NN
+ */
+SyL_Controller::streaming($config);
 
 ?>
