@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.11 2008/05/21 17:22:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.12 2008/06/20 17:41:54 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.11 2008/05/21 17:22:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.12 2008/06/20 17:41:54 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowLst extends SyL_AdmFlow
@@ -67,49 +67,6 @@ class SyL_AdmFlowLst extends SyL_AdmFlow
         parent::SyL_AdmFlow();
     }
 
-    /**
-     * ᥽åɼ¹˼¹Ԥ᥽å
-     *
-     * @access public
-     * @param object ǡ֥
-     * @param object ƥȥ֥
-     */
-    function preExecute(&$data, &$context)
-    {
-        // AJAXʸѴ
-        switch ($data->get('adm_ajax')) {
-        case 'import':
-        case 'json':
-            $data->apply('mb_convert_encoding', SYL_ENCODE_INTERNAL, SYL_ENCODE_JS);
-            break;
-        }
-        parent::preExecute($data, $context);
-    }
-
-    /**
-     * ᥽åɼ¹Ը˼¹Ԥ᥽å
-     * 
-     * @access public
-     * @param object ǡ֥
-     * @param object ƥȥ֥
-     */
-    function postExecute(&$data, &$context)
-    {
-        parent::postExecute($data, $context);
-
-        switch ($data->get('adm_ajax')) {
-        case 'import':
-            $data->apply('mb_convert_encoding', SYL_ENCODE_JS, SYL_ENCODE_INTERNAL);
-            $context->setViewType('js.default');
-            $data->addImport('ajax');
-            break;
-        case 'json':
-            $data->apply('mb_convert_encoding', SYL_ENCODE_JS, SYL_ENCODE_INTERNAL);
-            $context->setViewType('json');
-            break;
-        }
-    }
-
     /**
      * ɽե
      *
@@ -119,16 +76,17 @@ class SyL_AdmFlowLst extends SyL_AdmFlow
      */
     function execute(&$data, &$context)
     {
-        // JSݡȻϥ󥹥å
-        if ($data->get('adm_ajax') == 'import') {
-            return;
-        }
-
         // ѥ᡼
-        $sort = $data->get('sort');
-        $page = $data->get('page');
+        $page  = $data->get('_page');
+        $row   = $data->get('_row');
+        $sort  = $data->get('_sort');
         $index = $data->get('adm_list_index'); // AjaxξΤ߻
 
+        // ɽȽ
+        if (!is_numeric($row) || ($row < 1)) {
+            $row = '';
+        }
+
         // ե
         $form =& $this->getForm();
         // ǡ֥ȥå
@@ -151,7 +109,7 @@ class SyL_AdmFlowLst extends SyL_AdmFlow
         }
 
         // ɽǡ
-        $results = $adm->getList($sort, $page, '');
+        $results = $adm->getList($sort, $page, $row);
         // Ȥθѥ᡼
         $search_parameter = implode('&', $adm->getSearchParameters());
         // إåɽܼ
@@ -233,6 +191,134 @@ class SyL_AdmFlowLst extends SyL_AdmFlow
         // AjaxΤߡϢ󥯥ǥå
         $data->set('index', $index);
     }
+
+    /**
+     * Ajax饤֥ѥ
+     *
+     * @access public
+     * @param object ǡ֥
+     * @param object ƥȴ֥
+     */
+    function executeImport(&$data, &$context)
+    {
+        $data->addImport('ajax');
+        $context->setViewType('js.default');
+    }
+
+    /**
+     * JSONѥ
+     *
+     * @access public
+     * @param object ǡ֥
+     * @param object ƥȴ֥
+     */
+    function executeJson(&$data, &$context)
+    {
+        $data->apply('mb_convert_encoding', SYL_ENCODE_INTERNAL, SYL_ENCODE_JS);
+
+        // ѥ᡼
+        $page = $data->get('_page');
+        $row  = $data->get('_row');
+        $sort = $data->get('_sort');
+
+        // ɽȽ
+        if (!is_numeric($row) || ($row < 1)) {
+            $row = '';
+        }
+
+        // ե
+        $form =& $this->getForm();
+        // ǡ֥ȥå
+        $form->registerInput($data);
+        // ե๽
+        $form->buildSearch();
+
+        // DB³
+        $conn =& $context->getDB();
+
+        // ADM֥Ⱥ
+        $adm =& SyL_Adm::factory($form, $conn);
+        // ơ֥
+        $adm->loadConfig();
+        // å
+        if (!$adm->isLst()) {
+            $status = array(
+              'error' => true,
+              'errorMessage' => '403 Forbidden'
+            );
+            $data->set('status',  $status);
+            $data->set('header',  array());
+            $data->set('columns', array());
+            $data->apply('mb_convert_encoding', SYL_ENCODE_JS, SYL_ENCODE_INTERNAL);
+            $context->setViewType('json');
+            return;
+        }
+        // ɽǡ
+        $results = $adm->getList($sort, $page, $row);
+
+        // DB³λ
+        $context->closeDB($conn);
+
+        // إåɽܼ
+        $columns = $adm->getSelectHeaders();
+        // ȤΥȹܼ
+        list($current_sort) = explode(',', $adm->getSortColumns());
+        $pos = strrpos($current_sort, '.');
+        $current_order = substr($current_sort, $pos+1);
+        $current_sort  = substr($current_sort, 0, $pos);
+
+        // ڡ֥ȼ
+        $pager =& $adm->getPager();
+        $range = $form->getStructConfig('link_range');
+        $start_page = 0;
+        $end_page   = 0;
+        if (is_numeric($range)) {
+            list($start_page, $end_page) = $pager->getRange($range);
+        } else {
+            if ($pager->getCurrentPage() > 0) {
+                $start_page = 1;
+                $end_page   = $pager->getTotalPage();
+            }
+        }
+
+        // ץ饤ޥꥭ
+        $primarys = $adm->getPrimary(false);
+        $key = $form->getStructConfig('key_name');
+        foreach ($columns as $name => $values) {
+            $columns[$name]['sort'] = substr($values['sortlink'], 0, strrpos($values['sortlink'], '.'));
+            unset($columns[$name]['sortlink']);
+            if ((count($primarys) > 0) && ($primarys[0] == $name)) {
+                $link_params = array();
+                foreach ($primarys as $primary) {
+                    $link_params[] = $primary . '%3D{' . $primary . '}';
+                }
+                $columns[$name]['linkTemplate'] = $this->getUrl('vew') . '?' . $key . '=' . implode('%09', $link_params);
+            }
+        }
+
+        $status = array(
+          'error' => false,
+          'errorMessage' => ''
+        );
+
+        $headers = array(
+          'page'       => $pager->getCurrentPage(),
+          'startPage'  => $start_page,
+          'endPage'    => $end_page,
+          'row'        => $pager->getCount(),
+          'totalPage'  => $pager->getTotalPage(),
+          'totalCount' => $pager->getCountAll(),
+          'columns'    => $columns,
+          'sort'       => $current_sort,
+          'order'      => $current_order,
+        );
+
+        $data->set('status',  $status);
+        $data->set('header',  $headers);
+        $data->set('columns', $results);
+        $data->apply('mb_convert_encoding', SYL_ENCODE_JS, SYL_ENCODE_INTERNAL);
+        $context->setViewType('json');
+    }
 }
 
 ?>
