@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextWeb.php,v 1.10 2008/08/31 13:58:49 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextWeb.php,v 1.11 2008/09/23 09:06:16 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'SyL_ContextJs.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextWeb.php,v 1.10 2008/08/31 13:58:49 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextWeb.php,v 1.11 2008/09/23 09:06:16 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ContextWeb extends SyL_ContextJs
@@ -75,12 +75,11 @@ class SyL_ContextWeb extends SyL_ContextJs
      * 󥹥ȥ饯
      *
      * @access public
-     * @param object ȥ饪֥
      * @param object ǡ֥
      */
-    function SyL_ContextWeb(&$controller, &$data)
+    function SyL_ContextWeb(&$data)
     {
-        parent::SyL_ContextJs($controller, $data);
+        parent::SyL_ContextJs($data);
 
         if (!$data->getImport()) {
             $router =& SyL_Router::singleton();
@@ -90,8 +89,6 @@ class SyL_ContextWeb extends SyL_ContextJs
                 $this->setLayoutName($layout_name);
             }
         }
-
-        $this->controller =& $controller;
     }
 
     /**
@@ -130,7 +127,7 @@ class SyL_ContextWeb extends SyL_ContextJs
      */
     function getTemplateDir()
     {
-        return $this->controller->getTemplateDir() . '/';
+        return $this->template_dir;
     }
 
     /**
@@ -142,7 +139,7 @@ class SyL_ContextWeb extends SyL_ContextJs
      */
     function getTemplateFile($trigger_error_404=true)
     {
-        $template_dir  = $this->getTemplateDir();
+        $template_dir  = $this->template_dir . '/';
         $template_file = $this->template_file;
         if (preg_match('/^(\\\\|\/)(.+)$/', $template_file, $matches)) {
             $template_file = $matches[2];
