@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.13 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.14 2008/09/23 09:06:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,15 +48,15 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.13 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.14 2008/09/23 09:06:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ControllerWeb extends SyL_Controller
 {
     /**
-     * ȥݥ
+     * ¹ԴĶȤΥե
      *
-     * @access public
+     * @access protected
      */
     function stream()
     {
@@ -73,17 +73,6 @@ class SyL_ControllerWeb extends SyL_Controller
         // ӥ塼ɽ¹Ը
         $this->unloadStream();
     }
-
-    /**
-     * ƥץ졼ȥǥ쥯ȥ
-     *
-     * @access public
-     * @return string ƥץ졼ȥǥ쥯ȥ
-     */
-    function getTemplateDir()
-    {
-        return $this->template_dir;
-    }
 }
 
 ?>
