@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterParameter.php,v 1.20 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterParameter.php,v 1.21 2008/09/23 09:06:16 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterParameter.php,v 1.20 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterParameter.php,v 1.21 2008/09/23 09:06:16 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterParameter extends SyL_Router
@@ -55,21 +55,18 @@ class SyL_RouterParameter extends SyL_Router
     /**
      * ܾ󥪥֥ȤΥץѥƥ
      *
-     * @access protected
-     * @param object ꥯȥ֥
+     * @access public
+     * @param object ǡ֥
      */
     function createActionInfo(&$data)
     {
         $pathinfo = array();
         // ѥ᡼ SYL_ACTION_KEY Ǽѥ᡼
         $action   = $data->get(SYL_ACTION_KEY);
-        if (is_array($action)) {
-            if (count($action) > 0) {
-                $pathinfo = explode($this->action_delimiter, $action[0]);
-            }
-        } else {
-            $pathinfo = explode($this->action_delimiter, $action);
+        if ($action === null) {
+            $action = $data->geta(SYL_ACTION_KEY, 0);
         }
+        $pathinfo = explode($this->action_delimiter, $action);
 
         switch (count($pathinfo)) {
         case 0:
