@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.20 2008/08/31 13:58:49 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.21 2008/09/23 09:06:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,25 +48,25 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Loader.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.20 2008/08/31 13:58:49 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.21 2008/09/23 09:06:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Context
 {
     /**
-     * ѥ᡼
-     * 
-     * @access protected
+     * ǥ쥯ȥ롼
+     *
+     * @access private
      * @var string
      */
-    var $parameters = array();
+    var $action_dir = '';
     /**
-     * executeե¹ԥե饰
-     * 
-     * @access protected
-     * @var bool
+     * ƥץ졼ȥǥ쥯ȥ롼
+     *
+     * @access private
+     * @var string
      */
-    var $is_execute = true;
+    var $template_dir = '';
     /**
      * 󥯥饹
      * 
@@ -96,12 +96,19 @@ class SyL_Context
      */
     var $view_type = 'null';
     /**
-     * ȥ饪֥
+     * ѥ᡼
      * 
-     * @access private
-     * @var object
+     * @access protected
+     * @var string
      */
-    var $controller = null;
+    var $parameters = array();
+    /**
+     * executeե¹ԥե饰
+     * 
+     * @access protected
+     * @var bool
+     */
+    var $is_execute = true;
     /**
      * å奿ॢ[s]
      * 
@@ -120,11 +127,10 @@ class SyL_Context
     /**
      * 󥹥ȥ饯
      *
-     * @access public
-     * @param object ȥ饪֥
+     * @access protected
      * @param object ǡ֥
      */
-    function SyL_Context(&$controller, &$data)
+    function SyL_Context(&$data)
     {
         $router =& SyL_Router::singleton();
         $router->createActionInfo($data);
@@ -138,7 +144,10 @@ class SyL_Context
             $this->setViewType($view_type);
         }
 
-        $this->controller =& $controller;
+        // ǥ쥯ȥ
+        $this->action_dir = SYL_APP_DIR . '/actions';
+        // ƥץ졼ȥǥ쥯ȥ
+        $this->template_dir = SYL_APP_DIR . '/templates';
 
         if (SYL_CACHE) {
             $this->cache =& SyL_Cache::factory(SYL_CACHE);
@@ -153,17 +162,16 @@ class SyL_Context
      * ƥȤ
      *
      * @access public
-     * @param object ȥ饪֥
      * @param object ǡ֥
      */
-    function &getInstance(&$controller, &$data)
+    function &singleton(&$data)
     {
         static $singleton;
         if (!is_object($singleton)) {
             $class_name = 'SyL_Context' . ucfirst(SYL_ENV_TYPE);
             include_once SYL_INCLUDE_DIR . "/framework/Context/{$class_name}.php";
             // ҥ饹Υ󥹥
-            $singleton = new $class_name($controller, $data);
+            $singleton = new $class_name($data);
         }
         return $singleton;
     }
@@ -187,7 +195,7 @@ class SyL_Context
      */
     function getActionDir()
     {
-        return $this->controller->getActionDir();
+        return $this->action_dir;
     }
 
     /**
@@ -287,7 +295,7 @@ class SyL_Context
      */
     function &getComponent($name)
     {
-        $container =& $this->controller->getContainer();
+        $container =& SyL_Container::singleton();
         return $container->getComponent($name);
     }
 
