@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Data.php,v 1.9 2008/06/20 17:41:54 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Data.php,v 1.10 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilProperty.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Data.php,v 1.9 2008/06/20 17:41:54 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Data.php,v 1.10 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Data extends SyL_UtilProperty
@@ -56,6 +56,13 @@ class SyL_Data extends SyL_UtilProperty
      * @var array
      */
     var $input_parameters = array();
+    /**
+     * ѥ᡼get᥽åɤǼǤե饰
+     *
+     * @access protected
+     * @var bool
+     */
+    var $input_get_array = false;
 
     /**
      * ǡݻ饹Υ󥹥󥹼
@@ -143,6 +150,10 @@ class SyL_Data extends SyL_UtilProperty
         $value = parent::get($name);
         if (($value === null) && isset($this->input_parameters[$name])) {
             $value = $this->input_parameters[$name];
+            // ϥѥ᡼ϡgeta᥽åɤŪ˼
+            if (!$this->input_get_array && is_array($value)) {
+                $value = null;
+            }
         }
         if ($value === null) {
             return $default;
@@ -156,6 +167,26 @@ class SyL_Data extends SyL_UtilProperty
         }
     }
 
+    /**
+     * ϥѥ᡼Ū˼
+     * 
+     * @access public
+     * @param string ץѥƥ̾
+     * @return array ץѥƥ
+     */
+    function geta($name, $index=null)
+    {
+        if (isset($this->input_parameters[$name]) && is_array($this->input_parameters[$name])) {
+            if ($index !== null) {
+                return isset($this->input_parameters[$name][$index]) ? $this->input_parameters[$name][$index] : null;
+            } else {
+                return $this->input_parameters[$name];
+            }
+        } else {
+            return null;
+        }
+    }
+
     /**
      * ץѥƥʻȡ
      * 
@@ -170,6 +201,10 @@ class SyL_Data extends SyL_UtilProperty
         $value =& parent::getRef($name);
         if (($value === null) && isset($this->input_parameters[$name])) {
             $value =& $this->input_parameters[$name];
+            // ϥѥ᡼ϡgeta᥽åɤŪ˼
+            if (!$this->input_get_array && is_array($value)) {
+                $value = null;
+            }
         }
         if ($value === null) {
             return $default;
@@ -215,6 +250,28 @@ class SyL_Data extends SyL_UtilProperty
         return $values;
     }
 
+    /**
+     * get᥽åѥ᡼ե饰򥻥å
+     * 
+     * @access public
+     * @param bool ѥ᡼ե饰
+     */
+    function isGetArray($input_get_array=false)
+    {
+        $this->input_get_array = (bool)$input_get_array;
+    }
+
+    /**
+     * ϥѥ᡼
+     * 
+     * @access public
+     * @return int ϥѥ᡼
+     */
+    function getInitCount()
+    {
+        return count($this->input_parameters);
+    }
+
     /**
      * ץѥƥ
      * 
