@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2007 k.watanabe
+ * Copyright (C) 2006-2008 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilExecutionTime.php,v 1.2 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilExecutionTime.php,v 1.3 2008/01/15 09:19:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -37,9 +37,9 @@
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilExecutionTime.php,v 1.2 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilExecutionTime.php,v 1.3 2008/01/15 09:19:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  **/
 class SyL_UtilExecutionTime
@@ -120,10 +120,7 @@ class SyL_UtilExecutionTime
     function getExecutionTime()
     {
         $execution_time = $this->getNowMicroTime() - $this->timer_start;
-        if ($execution_time > 0) {
-            $execution_time = sprintf("%01.3f", round($execution_time, 3));
-        }
-        return $execution_time;
+        return sprintf("%01.3F", round($execution_time, 3));
     }
 }
 
