@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FileReader.php,v 1.2 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FileReader.php,v 1.3 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FileReader.php,v 1.2 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FileReader.php,v 1.3 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_FileReader extends SyL_File
@@ -123,17 +123,6 @@ class SyL_FileReader extends SyL_File
         }
     }
 
-    /**
-     * ե˽Ϥ
-     *
-     * @access public
-     * @param string å
-     */
-    function write($message)
-    {
-        trigger_error("[SyL error] Unable to write method in " . get_class($this) . " class", E_USER_ERROR);
-    }
-
     /**
      * եĤ
      *
@@ -149,28 +138,6 @@ class SyL_FileReader extends SyL_File
         }
     }
 
-    /**
-     * ե뤫Ƥɤ߹
-     *
-     * @access public
-     * @return string եΥǡ
-     */
-    function process()
-    {
-        if ($this->csv) {
-            $data[] = array();
-            $this->open();
-            while ($tmp = $this->read()) {
-                $data[] = $tmp;
-            }
-            $this->close();
-            return $data;
-        } else {
-            $data = file_get_contents($this->resource_name);
-            return is_string($data) ? $this->convertEncode($data) : $data;
-        }
-    }
-
     /**
      * ϥ󥳡ǥ󥰤Ѵ
      *
