@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FileWriter.php,v 1.4 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FileWriter.php,v 1.5 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FileWriter.php,v 1.4 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FileWriter.php,v 1.5 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_FileWriter extends SyL_File
@@ -64,17 +64,6 @@ class SyL_FileWriter extends SyL_File
         $this->setFileBuffer(0);
     }
 
-    /**
-     * ե뤫ɤ߹
-     *
-     * @access public
-     * @return string ϥǡ or bool(false) ɤ߹߽λ
-     */
-    function read()
-    {
-        trigger_error("[SyL error] Unable to read method in " . get_class($this) . " class", E_USER_ERROR);
-    }
-
     /**
      * ե˽Ϥ
      *
@@ -110,21 +99,6 @@ class SyL_FileWriter extends SyL_File
         $this->write($message);
     }
 
-    /**
-     * ե˽ϤϢν¹Ԥ
-     *
-     * @access public
-     * @param string ϥå
-     */
-    function process($message)
-    {
-        $this->open();
-        $this->write($message);
-        $this->close();
-
-        return null;
-    }
-
     /**
      * ϥ󥳡ǥ󥰤Ѵ
      *
