@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationConfigXml.php,v 1.4 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationConfigXml.php,v 1.5 2008/06/20 17:41:54 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -61,7 +61,7 @@ require_once dirname(__FILE__) . '/../../Xml/SyL_XmlReader.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationConfigXml.php,v 1.4 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationConfigXml.php,v 1.5 2008/06/20 17:41:54 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ValidationConfigXml extends SyL_ValidationConfig
@@ -89,7 +89,7 @@ class SyL_ValidationConfigXml extends SyL_ValidationConfig
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationConfigXml.php,v 1.4 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationConfigXml.php,v 1.5 2008/06/20 17:41:54 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ValidationConfigXmlReader extends SyL_XmlReader
@@ -128,7 +128,7 @@ class SyL_ValidationConfigXmlReader extends SyL_XmlReader
         case '/validations/validation':
             $validation = $attribute['name'];
             $this->config[$validation]      = array();
-            $this->config_name[$validation] = isset($attribute['displayName']) ? $attribute['displayName'] : '';
+            $this->config_name[$validation] = isset($attribute['displayName']) ? $attribute['displayName'] : $validation;
             $i = -1;
             break;
         case '/validations/validation/validator':
