@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.8 2008/09/11 13:06:59 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.9 2008/09/23 09:06:16 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ SyL_Loader::lib('File');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.8 2008/09/11 13:06:59 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.9 2008/09/23 09:06:16 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Index extends AppAction
@@ -88,40 +88,46 @@ class Index extends AppAction
             return;
         }
 
-        // ץȥǥ쥯ȥѥ᡼
         $project_dir = $data->geta('d', 0);
+        $app_name    = $data->geta('w', 0);
+        $action_name = $data->geta('a', 0);
+        $controller_dir = dirname($data->geta('c', 0));
+        $tablename   = $data->geta('t', 0);
+        $smarty_flag = $data->is('s');
+
+        // -------------------------------------------------
+        // ץȥǥ쥯ȥå
+        // -------------------------------------------------
         if (!$project_dir) {
-             $this->displayDefault($cmd, $data->get(0));
-             return;
+            trigger_error("[SyL error] Project directory (-d) not found", E_USER_ERROR);
+            exit;
         }
         if (!is_dir($project_dir)) {
             trigger_error("[SyL error] Project directory not found ({$project_dir})", E_USER_ERROR);
+            exit;
         }
 
-        // ץꥱ̾ѥ᡼
-        $app_name = $data->geta('w', 0);
+        // -------------------------------------------------
+        // ץꥱ̾å
+        // -------------------------------------------------
+        $app_dir = '';
         if (!$app_name) {
-             $this->displayDefault($cmd, $data->get(0));
-             return;
+            trigger_error("[SyL error] Application name (-w) not found", E_USER_ERROR);
+            exit;
         }
         $app_dir = "{$project_dir}/apps/{$app_name}"; 
         if (!is_dir($app_dir)) {
             trigger_error("[SyL error] Application directory not found ({$app_dir})", E_USER_ERROR);
+            exit;
         }
 
-        // ǥ쥯ȥѥ᡼
-        $action_name = $data->geta('a', 0);
-        // ȥѥ᡼
-        $controller_dir = dirname($data->geta('c', 0));
-
-        // ơ֥ѥ᡼
-        $tablename = $data->geta('t', 0);
+        // -------------------------------------------------
+        // ơ֥̾å
+        // -------------------------------------------------
         if (!$tablename) {
-             $this->displayDefault($cmd, $data->get(0));
-             return;
+            trigger_error("[SyL error] Table name (-t) not found", E_USER_ERROR);
+            exit;
         }
-        // Smartyѥ᡼
-        $smarty_flag = $data->is('s');
 
         $mkdirs = array();
 
