@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.2 2008/09/11 13:06:59 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.3 2008/09/23 09:06:16 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -40,6 +40,10 @@ SyL_Loader::lib('Filesystem');
  * ̥饹
  */
 SyL_Loader::lib('Compress');
+/**
+ * ᡼륯饹
+ */
+SyL_Loader::lib('Mail');
 
 /**
  * å饹
@@ -48,11 +52,26 @@ SyL_Loader::lib('Compress');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.2 2008/09/11 13:06:59 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.3 2008/09/23 09:06:16 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Index extends AppAction
 {
+    /**
+     * ᡼Υȥ
+     * 
+     * @access public
+     * @var string
+     */
+    var $mail_title = 'SyL Framework Log Report ';
+    /**
+     * ᡼Ƥκ祵
+     * 
+     * @access public
+     * @var int
+     */
+    var $mail_max_log_size = 502400; //500KB
+
     /**
      * ᥤ
      *
@@ -75,10 +94,11 @@ class Index extends AppAction
 
         $type        = strtolower($data->get(1));
         $project_dir = $data->geta('d', 0);
-        $app_name    = $data->geta('w', 0);
+        $app_names   = $data->geta('w');
         $category_name  = $data->geta('c', 0);
         $output_dir     = $data->geta('o', 0);
         $category_only  = $data->is('n');
+        $include_syslog = $data->is('l');
         $remove_log     = $data->is('r');
         $start_datetime = $data->geta('s', 0);
         $start_date     = null;
@@ -98,6 +118,8 @@ class Index extends AppAction
         case 'sysremove':
             $syslog = true;
             break;
+        case 'mail':
+            break;
         default:
             $this->displayDefault($cmd, $data->get(0));
             return;
@@ -121,14 +143,16 @@ class Index extends AppAction
         // -------------------------------------------------
         // ץꥱ̾å
         // -------------------------------------------------
-        if (!$app_name) {
+        if (!is_array($app_names) || (count($app_names) == 0)) {
             trigger_error("[SyL error] Application name (-w) not found", E_USER_ERROR);
             exit;
         }
-        $app_dir = "{$project_dir}apps/{$app_name}/";
-        if (!file_exists($app_dir)) {
-            trigger_error("[SyL error] Invalid application. Application directory not found ({$app_dir})", E_USER_ERROR);
-            exit;
+        foreach ($app_names as $app_name) {
+            $app_dir = "{$project_dir}apps/{$app_name}/";
+            if (!file_exists($app_dir)) {
+                trigger_error("[SyL error] Invalid application. Application directory not found ({$app_dir})", E_USER_ERROR);
+                exit;
+            }
         }
 
         // -------------------------------------------------
@@ -157,56 +181,45 @@ class Index extends AppAction
             $end_date = mktime(23, 59, 59, date('n', $end_datetime), date('j', $end_datetime), date('Y', $end_datetime));
         }
 
-        // -------------------------------------------------
-        // ե뤫
-        // -------------------------------------------------
-        $logfile = '';
-        if ($syslog) {
-            $logfile = "{$project_dir}/var/syslogs/{$app_name}/phperror_{YYYY}{MM}{DD}.log";
-        } else {
-            $project_config_file = "{$project_dir}config/defines.xml";
-            $app_config_file     = "{$project_dir}apps/{$app_name}/config/defines.xml";
-
-            if (!is_file($project_config_file)) {
-                trigger_error("[SyL error] `defines.xml' not found in project directory({$project_config_file})", E_USER_ERROR);
-            }
-
-            // ե
-            $config =& SyL_Config::factory('defines');
-            $config->setConfigFiles(array($app_config_file, $project_config_file));
-            $config->parseXml(false, false);
-            $values = $config->getConfig();
-
-            if (!isset($values['SYL_LOG_FILE']) || !$values['SYL_LOG_FILE']) {
-                trigger_error("[SyL error] `SYL_LOG_FILE' constant not defined in config file({$project_config_file} or {$app_config_file})", E_USER_ERROR);
-            }
-            $logfile = $values['SYL_LOG_FILE'];
-            $logfile = str_replace('{SYL_PROJECT_DIR}', $project_dir, $logfile);
-            $logfile = str_replace('{SYL_APP_NAME}',    $app_name,    $logfile);
-        }
-
-        $logfile_dir  = dirname($logfile);
-        $logfile_name = preg_quote(basename($logfile));
-        $logfile_name = str_replace('\\{YYYY\\}', '\\d{4}', $logfile_name);
-        $logfile_name = str_replace('\\{MM\\}',   '\\d{2}', $logfile_name);
-        $logfile_name = str_replace('\\{DD\\}',   '\\d{2}', $logfile_name);
-        $logfile_name_reg = '/^' . $logfile_name . '(\.gz)?$/';
-
-        // -------------------------------------------------
-        // оݥեե륿
-        // -------------------------------------------------
+        // оݤΥե
         $logfiles = array();
-        $dir =& SyL_Filesystem::factory($logfile_dir);
-        $dir->createTree();
-        foreach ($dir->getList() as $element) {
-            // ֥ե륿
-            $mtime = $element->getMtime();
-            if ($start_date && ($mtime < $start_date)) continue;
-            if ($end_date && ($mtime > $end_date)) continue;
-            // ե̾ե륿
-            $filename = $element->getName();
-            if (!preg_match($logfile_name_reg, basename($filename))) continue;
-            $logfiles[] = $filename;
+
+        // -------------------------------------------------
+        // ץꥱ˥ե롼
+        // -------------------------------------------------
+        foreach ($app_names as $app_name) {
+            $tmp_logfiles = array();
+            // ƥ
+            if ($syslog || $include_syslog) {
+                $logfile = "{$project_dir}/var/syslogs/{$app_name}/phperror_{YYYY}{MM}{DD}.log";
+                $tmp_logfiles[] = array($logfile, true);
+            }
+            // SyL
+            if (!$syslog) {
+                // ե뤫
+                $project_config_file = "{$project_dir}config/defines.xml";
+                $app_config_file     = "{$project_dir}apps/{$app_name}/config/defines.xml";
+
+                if (!is_file($project_config_file)) {
+                    trigger_error("[SyL error] `defines.xml' not found in project directory({$project_config_file})", E_USER_ERROR);
+                }
+
+                // ե
+                $config =& SyL_Config::factory('defines');
+                $config->setConfigFiles(array($app_config_file, $project_config_file));
+                $config->parseXml(false, false);
+                $values = $config->getConfig();
+
+                if (!isset($values['SYL_LOG_FILE']) || !$values['SYL_LOG_FILE']) {
+                    trigger_error("[SyL error] `SYL_LOG_FILE' constant not defined in config file({$project_config_file} or {$app_config_file})", E_USER_ERROR);
+                }
+                $logfile = $values['SYL_LOG_FILE'];
+                $logfile = str_replace('{SYL_PROJECT_DIR}', $project_dir, $logfile);
+                $logfile = str_replace('{SYL_APP_NAME}',    $app_name,    $logfile);
+                $tmp_logfiles[] = array($logfile, false);
+            }
+            // ʪեꥹȼ
+            $logfiles = array_merge($logfiles, $this->getLogfiles($tmp_logfiles, $start_date, $end_date));
         }
 
         // -------------------------------------------------
@@ -215,19 +228,19 @@ class Index extends AppAction
         switch ($type) {
         case 'archive':
         case 'sysarchive':
+            $output_dir = null;
             // ϥǥ쥯ȥå
             if ($output_dir) {
                 if (!is_dir($output_dir)) {
                     trigger_error("[SyL error] Invalid output_dir (-o) ({$output_dir})", E_USER_ERROR);
                     exit;
                 }
-            } else {
-                $output_dir = $logfile_dir;
             }
             $this->archiveLog($cmd, $logfiles, $output_dir, $remove_log);
             break;
         case 'view':
         case 'sysview':
+        case 'mail':
             // ƥ̾å
             if ($category_name !== null) {
                 switch ($category_name) {
@@ -242,7 +255,11 @@ class Index extends AppAction
                   exit;
                 }
             }
-            $this->viewLog($cmd, $syslog, $logfiles, $category_name, $category_only, $start_datetime, $end_datetime);
+            if ($type == 'mail') {
+                $this->mailLog($cmd, $logfiles, $category_name, $category_only, $start_datetime, $end_datetime);
+            } else {
+                $this->viewLog($cmd, $logfiles, $category_name, $category_only, $start_datetime, $end_datetime);
+            }
             break;
         case 'remove':
         case 'sysremove':
@@ -251,6 +268,42 @@ class Index extends AppAction
         }
     }
 
+    /**
+     * оݤΥե
+     *
+     * @access private
+     * @param array ե
+     * @param int աUNIX Time
+     * @param int λաUNIX Time
+     * @return array ե
+     */
+    function getLogfiles($tmp_logfiles, $start_date, $end_date)
+    {
+        $logfiles = array();
+        foreach ($tmp_logfiles as $tmp_logfile) {
+            $logfile_dir  = dirname($tmp_logfile[0]);
+            $logfile_name = preg_quote(basename($tmp_logfile[0]));
+            $logfile_name = str_replace('\\{YYYY\\}', '\\d{4}', $logfile_name);
+            $logfile_name = str_replace('\\{MM\\}',   '\\d{2}', $logfile_name);
+            $logfile_name = str_replace('\\{DD\\}',   '\\d{2}', $logfile_name);
+            $logfile_name_reg = '/^' . $logfile_name . '(\.gz)?$/';
+
+            $dir =& SyL_Filesystem::factory($logfile_dir);
+            $dir->createTree();
+            foreach ($dir->getList() as $element) {
+                // ֥ե륿
+                $mtime = $element->getMtime();
+                if ($start_date && ($mtime < $start_date)) continue;
+                if ($end_date && ($mtime > $end_date)) continue;
+                // ե̾ե륿
+                $filename = $element->getName();
+                if (!preg_match($logfile_name_reg, basename($filename))) continue;
+                $logfiles[] = array($filename, $tmp_logfile[1]);
+            }
+        }
+        return $logfiles;
+    }
+
     /**
      * 򰵽̤
      *
@@ -263,9 +316,16 @@ class Index extends AppAction
     function archiveLog(&$cmd, $logfiles, $output_dir, $remove_log)
     {
         foreach ($logfiles as $logfile) {
-            $output_file = $output_dir . '/' . basename($logfile) . '.gz';
-            SyL_Compress::compressFromFile('gzip', $logfile, $output_file, $remove_log);
-            $cmd->stdout("{$logfile} -> {$output_file}");
+            if (!preg_match('/\.gz$/', $logfile[0]) && (filesize($logfile[0]) > 0)) {
+                $output_file = '';
+                if ($output_dir) {
+                    $output_file = $output_dir . '/' . basename($logfile[0]) . '.gz';
+                } else {
+                    $output_file = $logfile[0] . '.gz';
+                }
+                SyL_Compress::compressFromFile('gzip', $logfile[0], $output_file, $remove_log);
+                $cmd->stdout("{$logfile[0]} -> {$output_file}");
+            }
         }
     }
 
@@ -274,22 +334,15 @@ class Index extends AppAction
      *
      * @access private
      * @param object ޥɥ֥
-     * @param bool PHPƥե饰
      * @param array ե
      * @param string ƥ̾
      * @param bool ꥫƥΤɽե饰
      * @param string 
      * @param string λ
+     * @param bool echoϥե饰
      */
-    function viewLog(&$cmd, $syslog, $logfiles, $category_name, $category_only, $start_datetime, $end_datetime)
+    function viewLog(&$cmd, $logfiles, $category_name, $category_only, $start_datetime, $end_datetime, $echo=false)
     {
-        $reg = '';
-        if ($syslog) {
-            $reg = '/^\[([^\]]+)\] PHP.* (error|Warning|Notice): .+/';
-        } else {
-            $reg = '/^(\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}) \[[^\]]+:([^\]]+)\] .+/';
-        }
-
         $categories = array(
             'none'   => SYL_LOG_NONE,
             'error'  => SYL_LOG_ERROR,
@@ -301,11 +354,18 @@ class Index extends AppAction
         $current_category = $category_name ? $categories[$category_name] : null;
 
         foreach ($logfiles as $logfile) {
-            $fp = null;
-            if (preg_match('/\.gz$/', $logfile)) {
-                $fp = fopen("compress.zlib://{$logfile}", 'rb');
+            $reg = '';
+            if ($logfile[1]) {
+                $reg = '/^\[([^\]]+)\] PHP.* (error|Warning|Notice): .+/';
             } else {
-                $fp = fopen($logfile, 'rb');
+                $reg = '/^(\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}) \[[^\]]+:([^\]]+)\] .+/';
+            }
+
+            $fp = null;
+            if (preg_match('/\.gz$/', $logfile[0])) {
+                $fp = fopen("compress.zlib://{$logfile[0]}", 'rb');
+            } else {
+                $fp = fopen($logfile[0], 'rb');
             }
             $line = '';
             $tmp_category = '';
@@ -313,9 +373,13 @@ class Index extends AppAction
                 $tmp = fgets($fp);
                 if (preg_match($reg, $tmp, $matches)) {
                     if ($line) {
-                        $cmd->stdout(rtrim($line));
+                        if ($echo) {
+                            echo rtrim($line)."\n";
+                        } else {
+                            $cmd->stdout(rtrim($line));
+                        }
                     }
-                    
+
                     $skip = false;
                     $current_datetime = strtotime($matches[1]);
                     if ($start_datetime && ($current_datetime < $start_datetime)) {
@@ -352,7 +416,11 @@ class Index extends AppAction
                 }
             }
             if ($line) {
-                $cmd->stdout(rtrim($line));
+                if ($echo) {
+                    echo rtrim($line)."\n";
+                } else {
+                    $cmd->stdout(rtrim($line));
+                }
             }
             fclose($fp);
         }
@@ -368,8 +436,81 @@ class Index extends AppAction
     function removeLog(&$cmd, $logfiles)
     {
         foreach ($logfiles as $logfile) {
-            if (unlink($logfile)) {
-                $cmd->stdout("remove: {$logfile}");
+            if (unlink($logfile[0])) {
+                $cmd->stdout("remove: {$logfile[0]}");
+            }
+        }
+    }
+
+    /**
+     * Ƥ᡼
+     *
+     * @access private
+     * @param object ޥɥ֥
+     * @param array ե
+     * @param string ƥ̾
+     * @param bool ꥫƥΤɽե饰
+     * @param string 
+     * @param string λ
+     */
+    function mailLog(&$cmd, $logfiles, $category_name, $category_only, $start_datetime, $end_datetime)
+    {
+        ob_start();
+        $this->viewLog($cmd, $logfiles, $category_name, $category_only, $start_datetime, $end_datetime, true);
+        $contents = ob_get_clean();
+
+        if ($contents) {
+            if (!defined('SYL_MAIL_TYPE') || !defined('SYL_MAIL_ADMIN_ADDRESS') ||
+                !SYL_MAIL_TYPE || !SYL_MAIL_ADMIN_ADDRESS) {
+                trigger_error("[SyL error] `SYL_MAIL_TYPE' or 'SYL_MAIL_ADMIN_ADDRESS' Constant not defined", E_USER_ERROR);
+            }
+
+            $start_date = null;
+            $end_date   = null;
+            if ($start_datetime) $start_date = date('Y/m/d', $start_datetime);
+            if ($end_datetime)   $end_date   = date('Y/m/d', $end_datetime);
+
+            // ᡼륿ȥղ
+            $mail_title = '';
+            if ($start_date == $end_date) {
+                if ($start_date == null) {
+                    $mail_title = $this->mail_title;
+                } else {
+                    $mail_title = "{$this->mail_title} ({$start_date})";
+                }
+            } else {
+                $mail_title = "{$this->mail_title} ({$start_date} - {$end_date})";
+            }
+
+            // ¹
+            $date = date('Y-m-d H:i:s');
+            // SyLΥС
+            $version     = SYL_VERSION;
+            $version_php = PHP_VERSION;
+            $uname       = php_uname();
+            // ᡼ʸ
+            $contents = substr($contents, 0, $this->mail_max_log_size);
+
+            $contents = <<< EOF
+SyL Framework Log info. {$date}
+----------------------------------------
+
+{$contents}
+
+----------------------------------------
+SyL Framework ver. {$version} on PHP {$version_php}
+{$uname}
+EOF;
+
+            // ᡼¹
+            $mail =& SyL_Mail::factorySend(SYL_MAIL_TYPE);
+            $message =& $mail->createMessage();
+            $message->setSubject($mail_title);
+            $message->setFrom(SYL_MAIL_ADMIN_ADDRESS);
+            $message->addTo(SYL_MAIL_ADMIN_ADDRESS);
+            $message->setBody($contents);
+            if (!$mail->send($message)) {
+                trigger_error("[SyL error] Can not Send mail. " . $mail->getErrorMessage(), E_USER_ERROR);
             }
         }
     }
@@ -385,21 +526,23 @@ class Index extends AppAction
     {
         $help = <<<EOF
 Usage:
-  php {$file} view -d <dir> -w <name> [-c <name>] [-n] [-s <datetime>] [-e <datetime>]
-  php {$file} archive -d <dir> -w <name> [-o <dir>] [-r] [-s <datetime>] [-e <datetime>]
-  php {$file} remove -d <dir> -w <name> [-s <datetime>] [-e <datetime>]
-  php {$file} sysview -d <dir> -w <name> [-c <name>] [-n] [-s <datetime>] [-e <datetime>]
-  php {$file} sysarchive -d <dir> -w <name> [-o <dir>] [-r] [-s <datetime>] [-e <datetime>]
-  php {$file} sysremove -d <dir> -w <name> [-s <datetime>] [-e <datetime>]
+  php {$file} view -d <dir> -w <name> [-w <name> ...] [-c <name>] [-n] [-l] [-s <datetime>] [-e <datetime>]
+  php {$file} archive -d <dir> -w <name> [-w <name> ...] [-o <dir>] [-r] [-l] [-s <datetime>] [-e <datetime>]
+  php {$file} remove -d <dir> -w <name> [-w <name> ...] [-s <datetime>] [-l] [-e <datetime>]
+  php {$file} sysview -d <dir> -w <name> [-w <name> ...] [-c <name>] [-n] [-s <datetime>] [-e <datetime>]
+  php {$file} sysarchive -d <dir> -w <name> [-w <name> ...] [-o <dir>] [-r] [-s <datetime>] [-e <datetime>]
+  php {$file} sysremove -d <dir> -w <name> [-w <name> ...] [-s <datetime>] [-e <datetime>]
+  php {$file} mail -d <dir> -w <name> [-w <name> ...] [-c <name>] [-n] [-l] [-s <datetime>] [-e <datetime>]
   php {$file} [option]
 
 Options:
   -d <dir>      project directory
   -w <name>     application name
-  -c <name>     log category name (default: all category)
+  -c <name>     log category name [error|warn|notice|info|debug] (default: all category)
   -n            category only (default: more than category)
   -o <dir>      archive output directory (default: log file directory)
   -r            remove archived log file (default: not remove)
+  -l            include php system log (default: not include)
   -s <datetime> start datetime (strtotime format) (default: none)
   -e <datetime> end datetime (strtotime format) (default: none)
   -h            show this help, then exit
