@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Template.php,v 1.2 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: Template.php,v 1.3 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,22 +39,13 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Template.php,v 1.2 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: Template.php,v 1.3 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Template extends AppAction
 {
     var $c_template; // 󥸥
 
-    /**
-     * 󥹥ȥ饯
-     *
-     * @access public
-     */
-    function Template()
-    {
-    }
-
     /**
      * ƥץ졼Ⱥ
      *
@@ -64,24 +55,22 @@ class Template extends AppAction
      */
     function execute(&$data, &$context)
     {
-        $project_dir    = $data->get('d');
-        $app_name       = $data->get('w');
-        $template_files = $data->get('t');
+        $project_dir    = $data->geta('d', 0);
+        $app_name       = $data->geta('w', 0);
+        $template_files = $data->geta('t');
+
+        $cmd =& $context->getConsole();
 
         // -------------------------------------------------
         // ץȥǥ쥯ȥå
         // -------------------------------------------------
-        $cnt = count($project_dir);
-        if ($cnt == 0) {
+        if (!$project_dir) {
             trigger_error("[SyL error] Project directory (-d) not found", E_USER_ERROR);
             exit;
-        } else if ($cnt > 1) {
-            trigger_error("[SyL error] Project directory (-d) only 1", E_USER_ERROR);
-            exit;
         }
-
-        $project_dir = preg_match('/(\\\\|\/)$/', $project_dir[0]) ? $project_dir[0] : $project_dir[0] . '/';
-
+        if (!preg_match('/(\\\\|\/)$/', $project_dir)) {
+            $project_dir .= '/';
+        }
         if (!file_exists($project_dir)) {
             trigger_error("[SyL error] Project directory not found ({$project_dir})", E_USER_ERROR);
             exit;
@@ -90,42 +79,34 @@ class Template extends AppAction
         // -------------------------------------------------
         // ץꥱ̾å
         // -------------------------------------------------
-        $cnt = count($app_name);
-        if ($cnt == 0) {
+        if (!$app_name) {
             trigger_error("[SyL error] Application name (-w) not found", E_USER_ERROR);
             exit;
-        } else if ($cnt > 1) {
-            trigger_error("[SyL error] Application name (-w) only 1", E_USER_ERROR);
-            exit;
-        } else if (!preg_match('/^[\w\-]+$/', $app_name[0])) {
+        } else if (!preg_match('/^[\w\-]+$/', $app_name)) {
             trigger_error("[SyL error] Application name format invalid. ([a-z][A-Z][0-9]-_ only)", E_USER_ERROR);
             exit;
-        } else {
-            $app_name = $app_name[0];
         }
 
-        $app_dir = $project_dir . 'app/' . $app_name . '/';
-
+        $app_dir = "{$project_dir}apps/{$app_name}/";
         if (!file_exists($app_dir)) {
-            trigger_error("[SyL error] Application directory not found ({$project_dir})", E_USER_ERROR);
+            trigger_error("[SyL error] Application directory not found ({$app_dir})", E_USER_ERROR);
             exit;
         }
 
         // -------------------------------------------------
         // ƥץ졼ȥեå
         // -------------------------------------------------
-        $template_dir = $app_dir . 'templates/';
-        $cnt = count($template_files);
-        if ($cnt == 0) {
-            trigger_error("[SyL error] Template file not found", E_USER_ERROR);
+        if (!is_array($template_files)) {
+            trigger_error("[SyL error] Template file (-t) not found", E_USER_ERROR);
             exit;
         }
 
+        $template_dir = "{$app_dir}templates/";
         foreach ($template_files as $template_file) {
-            if (!preg_match('/^(\\\\|\/)/', $template_file)) {
-                $template_file = '/' . $template_file;
+            if (preg_match('/^(\\\\|\/)/', $template_file)) {
+                $template_file = substr($template_file, 1);
             }
-            if (substr($template_file, -5) != '.html') {
+            if (!preg_match('/\.html$/', $template_file)) {
                 $template_file .= '.html';
             }
             if (file_exists($template_dir . $template_file)) {
@@ -134,10 +115,11 @@ class Template extends AppAction
             }
         }
 
+
         // -------------------------------------------------
         // ƥץ졼ȥե
         // -------------------------------------------------
-        $this->c_template->trigger($project_dir, $app_name, $template_files);
+        $this->c_template->trigger($cmd, $project_dir, $app_name, $template_files);
     }
 
 }
