@@ -22,9 +22,8 @@ $config = array(
 );
 
 /**
- * ե졼εư
+ * ե졼ư
  */
-$controller =& SyL_Controller::getController($config);
-$controller->stream();
+SyL_Controller::streaming($config);
 
 ?>
